#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_SUM_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_SUM_HPP_INCLUDED

#include <boost/simd/reduction/include/functions/sum.hpp>

#endif
